#
# spec file for package perl-pcsc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name pcsc-perl
Name:           perl-pcsc
VCS: https://src.suse.de/SLFO-pool/perl-pcsc#4880dcd6bbae07be073fd752d4af0c40747662773ec493a939cbcbf2dd348d23
Version:        1.4.16
Release:        160000.1.4
Summary:        Perl interface to Smart Card Reader
License:        GPL-2.0-or-later
Group:          Development/Libraries/Perl
URL:            https://github.com/LudovicRousseau/%{cpan_name}
Source:         https://pcsc-perl.apdu.fr/Chipcard-PCSC-v%{version}.tar.gz
Source1:        https://pcsc-perl.apdu.fr/Chipcard-PCSC-v%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  perl
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libpcsclite)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1130
BuildRequires:  perl-macros
Requires:       perl-base = %{perl_version}
%{perl_requires}
%else
Requires:       perl = %{perl_version}
%endif

%description
PC/SC represents an abstraction layer to smart card readers. It
provides a communication layer with a wide variety of smart card
readers through a standardized API.

%prep
%autosetup -n Chipcard-PCSC-v%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
# No daemon and no card in the sysroot => no test.
#make %{?_smp_mflags} test

%install
%perl_make_install
%perl_process_packlist
%if 0%{?suse_version} > 1130
%perl_gen_filelist
%else
touch %{name}.files
%endif

%files -f %{name}.files
%defattr(-,root,root,-)
%doc Changelog LICENCE README
%if 0%{?suse_version} <= 1130
%{perl_vendorarch}/Chipcard
%{perl_vendorarch}/auto/Chipcard
%doc %{_mandir}/man3/*
%{_localstatedir}/adm/perl-modules/%{name}
%endif

%changelog
* Mon Jul 29 2024 pgajdos@suse.com
- version update to 1.4.16
  * moved to github
  * modernize a bit
* Mon Jul 31 2017 sbrabec@suse.com
- Update to version 1.4.14:
  * Error processing fixes.
- Add gpg.keyring and pcsc-perl-1.4.14.tar.bz2.asc.
* Wed Dec  3 2014 mardnh@gmx.de
- update to version 1.4.13
- corrected Source URL
- ran spec-cleaner
- removed patch: pcsc-perl-noSCardSetTimeout.patch (included in upstream since 1.4.11)
- Changes since 1.4.10:
  * PCSC.pm: Support Perl 5.16
  Remove the warning:
  defined(@array) is deprecated at /usr/lib/perl/5.16.3/Chipcard/PCSC.pm line 69.
    (Maybe you should just omit the defined()?)
  Thanks to Viliam Pucik for the bug report
  * PCSC.xs: Also check for SVt_PVIV and not just SVt_IV.
  * PCSC.xs, PCSC.pm, test.pl: Use lines of less than 80 columns
  * PCSCperl.h: SCardCancelTransaction() is no more present in pcsc-lite
  * PCSC.pm, PCSC.pod, PCSC.xs, PCSCperl.h:
    SCardSetTimout is no more present in pcsc-lite > 1.6.4
    It was a pcsc-lite specific and deprecated function
* Thu Aug 18 2011 sbrabec@suse.cz
- Fix build for older products.
* Wed Aug 17 2011 sbrabec@suse.cz
- New package, version 1.4.10.
